@@ -1,14 +1,16 @@
 # ABSTRACT: Common Methods for Operating on Hash References
 package Bubblegum::Object::Hash;
 
+use 5.10.0;
 use Bubblegum::Class 'with';
 use Bubblegum::Constraints -types;
 
 with 'Bubblegum::Object::Role::Defined';
+with 'Bubblegum::Object::Role::Indirect';
 with 'Bubblegum::Object::Role::Keyed';
 with 'Bubblegum::Object::Role::Ref';
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 sub aslice {
     goto &array_slice;
@@ -20,6 +22,10 @@ sub array_slice {
     return [@{$self}{@keys}];
 }
 
+sub clear {
+    goto &empty;
+}
+
 sub defined {
     my $self = CORE::shift;
     my $key  = type_string CORE::shift;
@@ -226,7 +232,7 @@ Bubblegum::Object::Hash - Common Methods for Operating on Hash References
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -262,6 +268,13 @@ The array_slice method returns an array reference containing the values in the
 subject corresponding to the keys specified in the arguments in the order
 specified.
 
+=head2 clear
+
+    my $hash = {1..8};
+    $hash->clear; # {}
+
+The clear method is an alias to the empty method.
+
 =head2 defined
 
     my $hash = {1..8,9,undef};
@@ -496,6 +509,14 @@ elements in the subject.
 
 =encoding utf8
 
+=head1 SEE ALSO
+
+L<Bubblegum::Object::Array>, L<Bubblegum::Object::Code>,
+L<Bubblegum::Object::Hash>, L<Bubblegum::Object::Instance>,
+L<Bubblegum::Object::Integer>, L<Bubblegum::Object::Number>,
+L<Bubblegum::Object::Scalar>, L<Bubblegum::Object::String>,
+L<Bubblegum::Object::Undef>, L<Bubblegum::Object::Universal>,
+
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
