@@ -1,14 +1,16 @@
 # ABSTRACT: Common Methods for Operating on Defined Values
 package Bubblegum::Object::Universal;
 
+use 5.10.0;
 use Bubblegum::Exception;
 use Class::Forward;
 
 use Bubblegum::Class 'with';
 use Bubblegum::Constraints 'type_classname', 'type_object', 'type_string';
 use Class::Load 'load_class';
+use Scalar::Util 'blessed';
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 sub instance {
     my $self  = CORE::shift;
@@ -16,6 +18,12 @@ sub instance {
     return type_object $class->new(data => $self);
 }
 
+sub utils {
+    my $self = CORE::shift;
+    my $type = CORE::lc autobox::universal::type $self;
+    return wrapper($self, "${type}/utils");
+}
+
 sub wrapper {
     my $self    = CORE::shift;
     my $name    = type_string CORE::shift;
@@ -26,10 +34,10 @@ sub wrapper {
 }
 
 sub AUTOLOAD {
-    my $self  = shift;
+    my $self   = shift;
+    my $caller = caller;
     my ($class, $method) = split /::(\w+)$/, our $AUTOLOAD;
 
-    # hypocracy bug
     if ($self->can($method)) {
         unshift @_, $self;
         goto $self->can($method);
@@ -41,9 +49,10 @@ sub AUTOLOAD {
     }
 
     Bubblegum::Exception->throw(
-        $method->format(
+        verbose => 1,
+        message => $method->format(
             q(Can't locate object method "%s" via package "%s"),
-                ((ref $self || $self) || 'main')
+                ((blessed($self) ? ref $self : $caller) || 'main')
         )
     );
 }
@@ -62,7 +71,7 @@ Bubblegum::Object::Universal - Common Methods for Operating on Defined Values
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -107,6 +116,14 @@ L<Bubblegum::Wrapper::Yaml>.
 
 =encoding utf8
 
+=head1 SEE ALSO
+
+L<Bubblegum::Object::Array>, L<Bubblegum::Object::Code>,
+L<Bubblegum::Object::Hash>, L<Bubblegum::Object::Instance>,
+L<Bubblegum::Object::Integer>, L<Bubblegum::Object::Number>,
+L<Bubblegum::Object::Scalar>, L<Bubblegum::Object::String>,
+L<Bubblegum::Object::Undef>, L<Bubblegum::Object::Universal>,
+
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
