@@ -1,6 +1,7 @@
 # ABSTRACT: Bubblegum Wrapper around Hashing Algorithms
 package Bubblegum::Wrapper::Digest;
 
+use 5.10.0;
 use Bubblegum::Class;
 
 use Digest::MD5 ();
@@ -10,13 +11,16 @@ use Bubblegum::Exception;
 
 extends 'Bubblegum::Object::Instance';
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 sub BUILD {
     my $self = shift;
     $self->data->typeof('str')
         or Bubblegum::Exception->throw(
-            ref($self)->format('Wrapper package "%s" requires string data')
+            verbose => 1,
+            message => ref($self)->format(
+                'Wrapper package "%s" requires string data'
+            ),
         );
 }
 
@@ -51,7 +55,7 @@ Bubblegum::Wrapper::Digest - Bubblegum Wrapper around Hashing Algorithms
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
